@@ -1,7 +1,7 @@
 # coding: utf-8
 
 """
-Copyright (c) 2020 Aspose.Cells Cloud
+Copyright (c) 2022 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -28,12 +28,17 @@ from .models.above_average import AboveAverage
 from .models.access_token_response import AccessTokenResponse
 from .models.area import Area
 from .models.auto_fitter_options import AutoFitterOptions
+from .models.barcode_response import BarcodeResponse
+from .models.barcode_response_list import BarcodeResponseList
+from .models.batch_convert_request import BatchConvertRequest
 from .models.border import Border
 from .models.calculation_options import CalculationOptions
 from .models.cell_area import CellArea
 from .models.cell_value import CellValue
+from .models.cells_cloud_file_info import CellsCloudFileInfo
 from .models.cells_cloud_response import CellsCloudResponse
 from .models.cells_color import CellsColor
+from .models.cells_error import CellsError
 from .models.color import Color
 from .models.color_filter import ColorFilter
 from .models.color_filter_request import ColorFilterRequest
@@ -49,11 +54,12 @@ from .models.data_bar_border import DataBarBorder
 from .models.data_sorter import DataSorter
 from .models.disc_usage import DiscUsage
 from .models.dynamic_filter import DynamicFilter
-from .models.error import Error
 from .models.error_details import ErrorDetails
+from .models.file_info import FileInfo
 from .models.file_source import FileSource
 from .models.file_versions import FileVersions
 from .models.files_list import FilesList
+from .models.files_result import FilesResult
 from .models.files_upload_result import FilesUploadResult
 from .models.fill_format import FillFormat
 from .models.filter_column import FilterColumn
@@ -69,6 +75,7 @@ from .models.line import Line
 from .models.link import Link
 from .models.link_element import LinkElement
 from .models.list_column import ListColumn
+from .models.match_condition_request import MatchConditionRequest
 from .models.multiple_filter import MultipleFilter
 from .models.multiple_filters import MultipleFilters
 from .models.negative_bar_format import NegativeBarFormat
@@ -99,9 +106,13 @@ from .models.shadow_effect import ShadowEffect
 from .models.single_value import SingleValue
 from .models.solid_fill import SolidFill
 from .models.sort_key import SortKey
+from .models.sparkline import Sparkline
+from .models.sparkline_group import SparklineGroup
+from .models.sparkline_groups import SparklineGroups
 from .models.split_result import SplitResult
 from .models.storage_exist import StorageExist
 from .models.storage_file import StorageFile
+from .models.table_total_request import TableTotalRequest
 from .models.task_data import TaskData
 from .models.task_description import TaskDescription
 from .models.task_parameter import TaskParameter
@@ -152,7 +163,9 @@ from .models.conditional_formatting_response import ConditionalFormattingRespons
 from .models.conditional_formattings import ConditionalFormattings
 from .models.conditional_formattings_response import ConditionalFormattingsResponse
 from .models.convert_task_parameter import ConvertTaskParameter
+from .models.convert_worksheet_task_parameter import ConvertWorksheetTaskParameter
 from .models.dif_save_options import DifSaveOptions
+from .models.docx_save_options import DocxSaveOptions
 from .models.file_version import FileVersion
 from .models.fill_format_response import FillFormatResponse
 from .models.format_condition import FormatCondition
@@ -170,7 +183,9 @@ from .models.import_csv_data_option import ImportCSVDataOption
 from .models.import_data_task_parameter import ImportDataTaskParameter
 from .models.import_double_array_option import ImportDoubleArrayOption
 from .models.import_int_array_option import ImportIntArrayOption
+from .models.import_picture_option import ImportPictureOption
 from .models.import_string_array_option import ImportStringArrayOption
+from .models.json_save_options import JsonSaveOptions
 from .models.legend_response import LegendResponse
 from .models.line_format import LineFormat
 from .models.line_response import LineResponse
@@ -211,6 +226,7 @@ from .models.pivot_table_operate_parameter import PivotTableOperateParameter
 from .models.pivot_table_response import PivotTableResponse
 from .models.pivot_tables import PivotTables
 from .models.pivot_tables_response import PivotTablesResponse
+from .models.pptx_save_options import PptxSaveOptions
 from .models.range_value_response import RangeValueResponse
 from .models.ranges_response import RangesResponse
 from .models.row import Row
@@ -226,10 +242,13 @@ from .models.shapes import Shapes
 from .models.shapes_response import ShapesResponse
 from .models.single_value_response import SingleValueResponse
 from .models.smart_marker_task_parameter import SmartMarkerTaskParameter
+from .models.sparkline_group_response import SparklineGroupResponse
+from .models.sparkline_groups_response import SparklineGroupsResponse
 from .models.split_result_document import SplitResultDocument
 from .models.split_result_response import SplitResultResponse
 from .models.split_workbook_task_parameter import SplitWorkbookTaskParameter
 from .models.spreadsheet_ml2003_save_options import SpreadsheetML2003SaveOptions
+from .models.sql_script_save_options import SqlScriptSaveOptions
 from .models.style import Style
 from .models.style_response import StyleResponse
 from .models.svg_save_options import SvgSaveOptions
@@ -251,6 +270,7 @@ from .models.workbook_replace_response import WorkbookReplaceResponse
 from .models.workbook_response import WorkbookResponse
 from .models.workbook_settings_operate_parameter import WorkbookSettingsOperateParameter
 from .models.workbook_settings_response import WorkbookSettingsResponse
+from .models.worksheet_operate_parameter import WorksheetOperateParameter
 from .models.worksheet_replace_response import WorksheetReplaceResponse
 from .models.worksheet_response import WorksheetResponse
 from .models.worksheets import Worksheets
@@ -267,6 +287,7 @@ from .models.title import Title
 
 # import apis into sdk package
 from .apis.cells_api import CellsApi
+from .apis.light_cells_api import LightCellsApi
 
 # import ApiClient
 from .api_client import ApiClient
