@@ -1,7 +1,7 @@
 # coding: utf-8
 
 """
-Copyright (c) 2020 Aspose.Cells Cloud
+Copyright (c) 2022 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -28,12 +28,17 @@ from .above_average import AboveAverage
 from .access_token_response import AccessTokenResponse
 from .area import Area
 from .auto_fitter_options import AutoFitterOptions
+from .barcode_response import BarcodeResponse
+from .barcode_response_list import BarcodeResponseList
+from .batch_convert_request import BatchConvertRequest
 from .border import Border
 from .calculation_options import CalculationOptions
 from .cell_area import CellArea
 from .cell_value import CellValue
+from .cells_cloud_file_info import CellsCloudFileInfo
 from .cells_cloud_response import CellsCloudResponse
 from .cells_color import CellsColor
+from .cells_error import CellsError
 from .color import Color
 from .color_filter import ColorFilter
 from .color_filter_request import ColorFilterRequest
@@ -49,11 +54,12 @@ from .data_bar_border import DataBarBorder
 from .data_sorter import DataSorter
 from .disc_usage import DiscUsage
 from .dynamic_filter import DynamicFilter
-from .error import Error
 from .error_details import ErrorDetails
+from .file_info import FileInfo
 from .file_source import FileSource
 from .file_versions import FileVersions
 from .files_list import FilesList
+from .files_result import FilesResult
 from .files_upload_result import FilesUploadResult
 from .fill_format import FillFormat
 from .filter_column import FilterColumn
@@ -69,6 +75,7 @@ from .line import Line
 from .link import Link
 from .link_element import LinkElement
 from .list_column import ListColumn
+from .match_condition_request import MatchConditionRequest
 from .multiple_filter import MultipleFilter
 from .multiple_filters import MultipleFilters
 from .negative_bar_format import NegativeBarFormat
@@ -99,9 +106,13 @@ from .shadow_effect import ShadowEffect
 from .single_value import SingleValue
 from .solid_fill import SolidFill
 from .sort_key import SortKey
+from .sparkline import Sparkline
+from .sparkline_group import SparklineGroup
+from .sparkline_groups import SparklineGroups
 from .split_result import SplitResult
 from .storage_exist import StorageExist
 from .storage_file import StorageFile
+from .table_total_request import TableTotalRequest
 from .task_data import TaskData
 from .task_description import TaskDescription
 from .task_parameter import TaskParameter
@@ -152,7 +163,9 @@ from .conditional_formatting_response import ConditionalFormattingResponse
 from .conditional_formattings import ConditionalFormattings
 from .conditional_formattings_response import ConditionalFormattingsResponse
 from .convert_task_parameter import ConvertTaskParameter
+from .convert_worksheet_task_parameter import ConvertWorksheetTaskParameter
 from .dif_save_options import DifSaveOptions
+from .docx_save_options import DocxSaveOptions
 from .file_version import FileVersion
 from .fill_format_response import FillFormatResponse
 from .format_condition import FormatCondition
@@ -170,7 +183,9 @@ from .import_csv_data_option import ImportCSVDataOption
 from .import_data_task_parameter import ImportDataTaskParameter
 from .import_double_array_option import ImportDoubleArrayOption
 from .import_int_array_option import ImportIntArrayOption
+from .import_picture_option import ImportPictureOption
 from .import_string_array_option import ImportStringArrayOption
+from .json_save_options import JsonSaveOptions
 from .legend_response import LegendResponse
 from .line_format import LineFormat
 from .line_response import LineResponse
@@ -211,6 +226,7 @@ from .pivot_table_operate_parameter import PivotTableOperateParameter
 from .pivot_table_response import PivotTableResponse
 from .pivot_tables import PivotTables
 from .pivot_tables_response import PivotTablesResponse
+from .pptx_save_options import PptxSaveOptions
 from .range_value_response import RangeValueResponse
 from .ranges_response import RangesResponse
 from .row import Row
@@ -226,10 +242,13 @@ from .shapes import Shapes
 from .shapes_response import ShapesResponse
 from .single_value_response import SingleValueResponse
 from .smart_marker_task_parameter import SmartMarkerTaskParameter
+from .sparkline_group_response import SparklineGroupResponse
+from .sparkline_groups_response import SparklineGroupsResponse
 from .split_result_document import SplitResultDocument
 from .split_result_response import SplitResultResponse
 from .split_workbook_task_parameter import SplitWorkbookTaskParameter
 from .spreadsheet_ml2003_save_options import SpreadsheetML2003SaveOptions
+from .sql_script_save_options import SqlScriptSaveOptions
 from .style import Style
 from .style_response import StyleResponse
 from .svg_save_options import SvgSaveOptions
@@ -251,6 +270,7 @@ from .workbook_replace_response import WorkbookReplaceResponse
 from .workbook_response import WorkbookResponse
 from .workbook_settings_operate_parameter import WorkbookSettingsOperateParameter
 from .workbook_settings_response import WorkbookSettingsResponse
+from .worksheet_operate_parameter import WorksheetOperateParameter
 from .worksheet_replace_response import WorksheetReplaceResponse
 from .worksheet_response import WorksheetResponse
 from .worksheets import Worksheets
